@@ -202,6 +202,12 @@ on_goto_page_activate                  (GtkMenuItem     *menu_item,
 void
 on_fullscreen_activate                 (GtkMenuItem     *menu_item,
 					gpointer         user_data);
+
 void
-on_toggle_btn_clicked                  (GtkButton       *button,
-					gpointer         user_data);
+on_conf_special_accel_tview_realize    (GtkWidget       *widget,
+                                        gpointer         user_data);
+
+void
+on_conf_special_accel_tview_cursor_changed
+                                        (GtkTreeView     *treeview,
+                                        gpointer         user_data);
