@@ -9,9 +9,14 @@
 #include <stdlib.h>
 #ifdef USE_HILDON
 #    include <hildon/hildon-program.h>
-#    include <hildon/hildon-defines.h>
-#    define DEFAULT_WIDTH 700
-#    define DEFAULT_HEIGHT 480
+#    ifdef USE_FREMANTLE
+#	    include <hildon/hildon-defines.h>
+#	    define DEFAULT_WIDTH 800
+#	    define DEFAULT_HEIGHT 424
+#    else
+#	    define DEFAULT_WIDTH 700
+#	    define DEFAULT_HEIGHT 480
+#    endif
 #    define DEFAULT_BUFFER_SIZE (10*1024)
 #    define GCONF_DIR "/apps/Maemo/" prog_name "/"
 #else
@@ -231,11 +236,11 @@ load_config(void)
 
   strcpy(pref.lastbook, 
 	 p = gconf_client_get_string_with_default(client, GCONF_DIR "global/lastbook", ""));
-  g_free(p);
+  if (p != NULL) g_free(p);
 
   strcpy(pref.fixeddir, 
 	 p = gconf_client_get_string_with_default(client, GCONF_DIR "global/fixed_dir", ""));
-  g_free(p);
+  if (p != NULL) g_free(p);
 
   pref.nextpage = gconf_client_get_int_with_default(client, GCONF_DIR "global/nextpage", 0);
   pref.prevpage = gconf_client_get_int_with_default(client, GCONF_DIR "global/prevpage", 0);
